@@ -35,7 +35,7 @@ class Recipe(GenericBaseRecipe):
 
     base_path = options['base-path']
     if options.get('use-hash-url', 'True') in ['true', 'True']:
-      pool = string.letters + string.digits
+      pool = string.ascii_letters + string.digits
       hash_string = ''.join(random.choice(pool) for i in range(64))
       path = os.path.join(base_path, hash_string)
   
